==> haskell-cheapskate-0.1.0.4-3-armv7h.pkg.tar.xz: usr/share/haskell/haskell-cheapskate/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cheapskate
version: 0.1.0.4
id: cheapskate-0.1.0.4-e557ec3c71a5c54393cb7858ae743fb3
key: cheap_DdSeXMaaIfgArFuTItE820
license: BSD3
copyright: (C) 2012-2013 John MacFarlane
maintainer: jgm@berkeley.edu
homepage: http://github.com/jgm/cheapskate
synopsis: Experimental markdown processor.
description:
    This is an experimental Markdown processor in pure
    Haskell.  It aims to process Markdown efficiently and in
    the most forgiving possible way.  It is designed to deal
    with any input, including garbage, with linear
    performance.  Output is sanitized by default for
    protection against XSS attacks.
    .
    Several markdown extensions are implemented, including
    fenced code blocks, significant list start numbers, and
    autolinked URLs.  See README.markdown for details.
category: Text
author: John MacFarlane
exposed: True
exposed-modules:
    Cheapskate Cheapskate.Parse Cheapskate.Types Cheapskate.Html
hidden-modules: Cheapskate.Util Cheapskate.Inlines
                Cheapskate.ParserCombinators Paths_cheapskate
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/cheapskate-0.1.0.4
library-dirs: /usr/lib/ghc-7.10.3/site-local/cheapskate-0.1.0.4
data-dir: /usr/share/arm-linux-ghc-7.10.3/cheapskate-0.1.0.4
hs-libraries: HScheapskate-0.1.0.4-DdSeXMaaIfgArFuTItE820
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-html-0.8.1.1-59ea4b5f01886f370857b4d16361c2fc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    syb-0.6-56a5944f55f7a9d47e7b770375c0e1ae
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    uniplate-1.6.12-8f24c9f82f93b9dabcf5d8b53ffd592c
    xss-sanitize-0.3.5.6-230d5bf7daf3200c6f0f5ce353de0f41
haddock-interfaces: /usr/share/doc/haskell-cheapskate/html/cheapskate.haddock
haddock-html: /usr/share/doc/haskell-cheapskate/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cheapskate-0.1.0.4-14-armv7h.pkg.tar.xz: usr/share/haskell/haskell-cheapskate/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cheapskate
version: 0.1.0.4
id: cheapskate-0.1.0.4-e7084c4882f04909c69473a4ceb8b891
key: cheap_4gBbzsQgbCzJLY3OiCuVWd
license: BSD3
copyright: (C) 2012-2013 John MacFarlane
maintainer: jgm@berkeley.edu
homepage: http://github.com/jgm/cheapskate
synopsis: Experimental markdown processor.
description:
    This is an experimental Markdown processor in pure
    Haskell.  It aims to process Markdown efficiently and in
    the most forgiving possible way.  It is designed to deal
    with any input, including garbage, with linear
    performance.  Output is sanitized by default for
    protection against XSS attacks.
    .
    Several markdown extensions are implemented, including
    fenced code blocks, significant list start numbers, and
    autolinked URLs.  See README.markdown for details.
category: Text
author: John MacFarlane
exposed: True
exposed-modules:
    Cheapskate Cheapskate.Parse Cheapskate.Types Cheapskate.Html
hidden-modules: Cheapskate.Util Cheapskate.Inlines
                Cheapskate.ParserCombinators Paths_cheapskate
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/cheapskate-0.1.0.4
library-dirs: /usr/lib/ghc-7.10.3/site-local/cheapskate-0.1.0.4
data-dir: /usr/share/arm-linux-ghc-7.10.3/cheapskate-0.1.0.4
hs-libraries: HScheapskate-0.1.0.4-4gBbzsQgbCzJLY3OiCuVWd
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-html-0.8.1.1-59ea4b5f01886f370857b4d16361c2fc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    syb-0.6-56a5944f55f7a9d47e7b770375c0e1ae
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    uniplate-1.6.12-5a2a0a6de90df137bffce599d35d6149
    xss-sanitize-0.3.5.6-b3b679ace14b1ead6abf3b67e5cfe55e
haddock-interfaces: /usr/share/doc/haskell-cheapskate/html/cheapskate.haddock
haddock-html: /usr/share/doc/haskell-cheapskate/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
